@@ -17,7 +17,8 @@ from Queue import Empty, Queue as _Queue
 from kombu import exceptions
 from kombu.transport import get_transport_cls
 from kombu.simple import SimpleQueue, SimpleBuffer
-from kombu.utils import retry_over_time, OrderedDict
+from kombu.utils import retry_over_time
+from kombu.utils.compat import OrderedDict
 from kombu.utils.functional import wraps
 
 
@@ -102,15 +103,13 @@ class BrokerConnection(object):
         return self.transport.drain_events(self.connection, **kwargs)
 
     def _close(self):
-        try:
-            if self._connection:
-                try:
-                    self.transport.close_connection(self._connection)
-                except self.transport.connection_errors + (AttributeError, ):
-                    pass
-                self._connection = None
-        except socket.error:
-            pass
+        if self._connection:
+            try:
+                self.transport.close_connection(self._connection)
+            except self.transport.connection_errors + (AttributeError,
+                                                       socket.error):
+                pass
+            self._connection = None
         self._closed = True
 
     def release(self):
